@@ -1,11 +1,13 @@
 package Email::Sender::Transport::Wrapper;
 {
-  $Email::Sender::Transport::Wrapper::VERSION = '1.300002';
+  $Email::Sender::Transport::Wrapper::VERSION = '1.300003';
 }
 use Moo;
 with 'Email::Sender::Transport';
 # ABSTRACT: a mailer to wrap a mailer for mailing mail
 
+use Email::Sender::Util;
+
 
 has transport => (
   is   => 'ro',
@@ -19,6 +21,33 @@ sub send_email {
   $self->transport->send_email(@_);
 }
 
+sub is_simple {
+  return $_[0]->transport->is_simple;
+}
+
+sub allow_partial_success {
+  return $_[0]->transport->allow_partial_success;
+}
+
+sub BUILDARGS {
+  my $self = shift;
+  my $href = $self->SUPER::BUILDARGS(@_);
+
+  if (my $class = delete $href->{transport_class}) {
+    Carp::confess("given both a transport and transport_class")
+      if $href->{transport};
+
+    my %arg;
+    for my $key (map {; /^transport_arg_(.+)$/ ? "$1" : () } keys %$href) {
+      $arg{$key} = delete $href->{"transport_arg_$key"};
+    }
+
+    $href->{transport} = Email::Sender::Util->_easy_transport($class, \%arg);
+  }
+
+  return $href;
+}
+
 no Moo;
 1;
 
@@ -32,7 +61,7 @@ Email::Sender::Transport::Wrapper - a mailer to wrap a mailer for mailing mail
 
 =head1 VERSION
 
-version 1.300002
+version 1.300003
 
 =head1 DESCRIPTION
 
